@@ -12,7 +12,7 @@ class NegativeBinomial(RVDiscrete1dMixin):
 
         raise NotImplementedError
         self._r: int = r
-        self._p: float = p
+        self._x: float = p
         self._reset_distribution()
 
     def _reset_distribution(self):
