@@ -5,28 +5,35 @@ from numpy.linalg import norm
 from numpy.ma import clip
 from pandas import Series, MultiIndex
 from scipy.stats import rv_continuous
-from typing import overload, Iterable, Union
+from typing import overload, Iterable, Union, Optional
 
 from mpl_format.axes.axis_utils import new_axes
 
+from probability.distributions.mixins.plottable_mixin import PlottableMixin
+
 
 class ContinuousFunctionNd(object):
 
-    def __init__(self, distribution: rv_continuous, method_name: str, name: str,
-                 num_dims: int, parent: object):
+    def __init__(self,
+                 distribution: rv_continuous,
+                 method_name: str,
+                 name: str,
+                 num_dims: int,
+                 parent: PlottableMixin):
         """
         :param distribution: The scipy distribution to calculate with.
         :param method_name: The name of the method to call on the distribution.
         :param name: An intuitive name for the function.
         :param num_dims: The number of dimensions, K, of the function.
-        :param parent: The parent distribution object, used to call str(...) for series labels.
+        :param parent: The parent distribution object, used to call str(...) for
+                       series labels.
         """
         self._distribution = distribution
         self._num_dims = num_dims
         self._method_name: str = method_name
         self._name: str = name
         self._method = getattr(distribution, method_name)
-        self._parent: object = parent
+        self._parent: PlottableMixin = parent
 
     @overload
     def at(self, x: Iterable[float]) -> float:
@@ -44,7 +51,9 @@ class ContinuousFunctionNd(object):
         """
         Evaluate the function for each value of [x1, x2, ..., xk] given as x.
 
-        :param x: [x1, x2, ..., xk] or [[x11, x12, ..., x1k], [x21, x22, ..., x2k], ...]
+        :param x: [x1, x2, ..., xk] or [[x11, x12, ..., x1k],
+                                        [x21, x22, ..., x2k],
+                                        ...]
         """
         x = array(x)
         if x.ndim == 1:
@@ -57,8 +66,10 @@ class ContinuousFunctionNd(object):
                 ), data=self._method(x), name=f'{self._name}({self._parent})'
             )
 
-    def plot_2d(self, x1: Union[Iterable, ndarray], x2: Union[Iterable, ndarray],
-                color_map: str = 'viridis', ax: Axes = None) -> Axes:
+    def plot_2d(self,
+                x1: Union[Iterable, ndarray], x2: Union[Iterable, ndarray],
+                color_map: str = 'viridis', ax: Optional[Axes] = None,
+                **kwargs) -> Axes:
         """
         Plot a 2-dimensional function as a grid heat-map.
 
@@ -66,26 +77,30 @@ class ContinuousFunctionNd(object):
         :param x2: Range of values of x2 to plot p(x1, x2) over.
         :param color_map: Optional colormap for the heat-map.
         :param ax: Optional matplotlib axes to plot on.
+        :param kwargs: Additional arguments for contourf method.
         """
         x1_grid, x2_grid = meshgrid(x1, x2)
         x1_x2 = dstack((x1_grid, x2_grid))
         f = self._method(x1_x2)
         ax = ax or new_axes()
-        ax.contourf(x1_grid, x2_grid, f, cmap=color_map)
+        ax.contourf(x1_grid, x2_grid, f, cmap=color_map, **kwargs)
         ax.set_xlabel('x1')
         ax.set_ylabel('x2')
         return ax
 
     def plot_simplex(self, num_contours: int = 100, num_sub_div: int = 8,
-                     color_map: str = 'viridis', border: bool = True, ax: Axes = None) -> Axes:
+                     color_map: str = 'viridis', border: bool = True,
+                     ax: Optional[Axes] = None,
+                     **kwargs) -> Axes:
         """
         Plot a 3-dimensional functions as a simplex heat-map.
 
         :param num_contours: The number of levels of contours to plot.
         :param num_sub_div: Number of recursive subdivisions to create.
         :param color_map: Optional colormap for the plot.
-        :param border: Whether to plot a border around the simplex heatmap.
+        :param border: Whether to plot a border around the simplex heat-map.
         :param ax: Optional matplotlib axes to plot on.
+        :param kwargs: Additional arguments for tricontourf method.
         """
 
         corners = array([[0, 0], [1, 0], [0.5, 0.75 ** 0.5]])
@@ -101,7 +116,9 @@ class ContinuousFunctionNd(object):
 
             :param cartesian: A length-2 sequence containing the x and y value.
             """
-            s = [(corners[i] - mid_points[i]).dot(cartesian - mid_points[i]) / 0.75
+            s = [(corners[i] - mid_points[i]).dot(
+                     cartesian - mid_points[i]
+                 ) / 0.75
                  for i in range(3)]
             s_clipped = clip(a=s, a_min=0, a_max=1)
             return s_clipped / norm(s_clipped, ord=1)
@@ -111,7 +128,7 @@ class ContinuousFunctionNd(object):
         f = [self._method(to_barycentric(xy))
              for xy in zip(tri_mesh.x, tri_mesh.y)]
         ax = ax or new_axes()
-        ax.tricontourf(tri_mesh, f, num_contours, cmap=color_map)
+        ax.tricontourf(tri_mesh, f, num_contours, cmap=color_map, **kwargs)
         ax.set_aspect('equal')
         ax.set_xlim(0, 1)
         ax.set_ylim(0, 0.75 ** 0.5)
